/*
 * Created on 9 janv. 2004 by rosmord.
 *
 * This code is distributed under the LGPL.
 *  
 */
package application;

import java.sql.SQLException;

import ui.*;
import workflow.*;
import persistence.*;

/**
 * @author rosmord
 *
 */
public class AgendaApplication {
	AgendaUI ui;
	SimpleIO io;
	PersonneDAO persisteur;
	AjoutPersonneUI ajoutPersonne;
	AjoutPersonneWorkflow ajoutPersonneWorkflow;
	ListerPersonnesUI listerPersonne;
	ListerPersonnesWorkflow listerPersonneWorkFlow;
	
	
	public AgendaApplication(String url, String login, String password)
		throws SQLException, ClassNotFoundException {
		// classe pour les entres/sorties
		io = new SimpleIO();
		// chargement du driver.
		Class.forName("org.postgresql.Driver");
		persisteur = new PersonneDAO(url, login, password);

		// Cration des diffrentes interfaces.
		ajoutPersonneWorkflow = new AjoutPersonneWorkflow(persisteur);
		ajoutPersonne = new AjoutPersonneUI(io, ajoutPersonneWorkflow);

		listerPersonneWorkFlow = new ListerPersonnesWorkflow(persisteur);
		listerPersonne = new ListerPersonnesUI(io, listerPersonneWorkFlow);

	
		ui= new AgendaUI(io);
		ui.setAjoutPersonne(ajoutPersonne);
		ui.setListerPersonne(listerPersonne);
	}

	public void executer() {
		ui.executer();
	}

	public static void main(String[] args)
		throws SQLException, ClassNotFoundException {
			if (args.length != 3) {
				System.err.println("Attention, lancez ce programme en passant");
				System.err.println("en argument l'url de la base, votre login, et le mot de passe");
				System.err.println("vous pouvez crire un script shell en mode 700 pour automatiser le lancement");
				System.exit(1);
			}
		AgendaApplication app =
			new AgendaApplication(args[0], args[1], args[2]);
		app.executer();
	}
}
