package persistence;

import java.sql.*;
import java.util.Vector;
import modele.Personne;
/**
 * Cette classe gre les intractions avec la base de donnes.
 * This file is free Software
 * 
 * Note : la gestion d'erreurs est trs trs minime.
 * (c) Serge Rosmorduc
 * @author rosmord
 *
 */

public class PersonneDAO {

	private Connection db;

	// PreparedStatement utiliss
	private PreparedStatement getMaxPersonneIDStmt;
	private PreparedStatement createPersonneStmt;
	private PreparedStatement getPersonnesParInitialesStmt;
	
	static final String getMaxPersonneIDRequete =
		"select max(idPersonne) from personne";
		
	static final String createPersonneRequete =
		"insert into personne values(?,?,?)";
	
	static final String getPersonnesParInitialesRequete =
		"select * from Personne where nom LIKE ? ";
		

	public PersonneDAO(String url, String user, String pwd)
		throws SQLException {
		// On suppose que le driver a t charg.
		db = DriverManager.getConnection(url, user, pwd);
		getMaxPersonneIDStmt = db.prepareStatement(getMaxPersonneIDRequete);
		createPersonneStmt = db.prepareStatement(createPersonneRequete);
		getPersonnesParInitialesStmt =
			db.prepareStatement(getPersonnesParInitialesRequete);
	}

	/**
	 * Cre une personne dans la base.
	 * @param p
	 */
	public void create(Personne p) {
		try {
			createPersonneStmt.setInt(1, p.getIdPersonne());
			createPersonneStmt.setString(2, p.getNom());
			createPersonneStmt.setString(3, p.getPrenom());
			createPersonneStmt.executeUpdate();
		} catch (SQLException e) {
			e.printStackTrace();
		}
	}


	/**
	 * Method getMaxPersonneID.
	 * @return int
	 */
	public int getMaxPersonneID() {
		int result = 0;
		try {
			ResultSet rs = getMaxPersonneIDStmt.executeQuery();

			if (rs.next()) {
				result = rs.getInt(1);
			}

		} catch (SQLException e) {
			e.printStackTrace();
		}
		return result;
	}


	public Vector getPersonnesParInitiales(String debut) {
		Vector v= new Vector();
		ResultSet r = null;
		String aChercher = debut + "%";
		try {
			getPersonnesParInitialesStmt.setString(1, aChercher);
			r = getPersonnesParInitialesStmt.executeQuery();
			while(r.next()) {
				Personne p;
				p= new Personne(r.getInt("IdPersonne"), 
					r.getString("nom"), r.getString("prenom"));
				v.add(p);
			}
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return v;
	}
}
